@@ -1,25 +1,24 @@
 import unicodedata
 from collections import OrderedDict
-from typing import Optional
+from typing import List, Optional
 
-from django.conf import settings
 from django.contrib.auth import REDIRECT_FIELD_NAME, get_user_model
-from django.core.exceptions import FieldDoesNotExist
 from django.db import models
 from django.db.models import Q
-from django.utils.encoding import force_str
 from django.utils.http import base36_to_int, int_to_base36
 
 from allauth.account import app_settings
 from allauth.account.adapter import get_adapter
 from allauth.account.internal import flows
+from allauth.account.internal.emailkit import valid_email_or_none
+from allauth.account.internal.userkit import default_user_display  # noqa
+from allauth.account.internal.userkit import user_display  # noqa
+from allauth.account.internal.userkit import user_email  # noqa
+from allauth.account.internal.userkit import user_field  # noqa
+from allauth.account.internal.userkit import user_username  # noqa
 from allauth.account.models import Login
 from allauth.core.internal import httpkit
-from allauth.utils import (
-    get_request_param,
-    import_callable,
-    valid_email_or_none,
-)
+from allauth.utils import get_request_param
 
 
 def _unicode_ci_compare(s1, s2) -> bool:
@@ -64,66 +63,6 @@ def get_login_redirect_url(
     return ret
 
 
-_user_display_callable = None
-
-
-def default_user_display(user) -> str:
-    ret = ""
-    if app_settings.USER_MODEL_USERNAME_FIELD:
-        ret = getattr(user, app_settings.USER_MODEL_USERNAME_FIELD)
-    return ret or force_str(user) or user._meta.verbose_name
-
-
-def user_display(user) -> str:
-    global _user_display_callable
-    if not _user_display_callable:
-        f = getattr(settings, "ACCOUNT_USER_DISPLAY", default_user_display)
-        _user_display_callable = import_callable(f)
-    return _user_display_callable(user)
-
-
-def user_field(user, field, *args, commit=False):
-    """
-    Gets or sets (optional) user model fields. No-op if fields do not exist.
-    """
-    if not field:
-        return
-    User = get_user_model()
-    try:
-        field_meta = User._meta.get_field(field)
-        max_length = field_meta.max_length
-    except FieldDoesNotExist:
-        if not hasattr(user, field):
-            return
-        max_length = None
-    if args:
-        # Setter
-        v = args[0]
-        if v:
-            v = v[0:max_length]
-        setattr(user, field, v)
-        if commit:
-            user.save(update_fields=[field])
-    else:
-        # Getter
-        return getattr(user, field)
-
-
-def user_username(user, *args, commit=False):
-    if args and not app_settings.PRESERVE_USERNAME_CASING and args[0]:
-        args = [args[0].lower()]
-    return user_field(user, app_settings.USER_MODEL_USERNAME_FIELD, *args)
-
-
-def user_email(user, *args, commit=False):
-    if args and args[0]:
-        args = [args[0].lower()]
-    ret = user_field(user, app_settings.USER_MODEL_EMAIL_FIELD, *args, commit=commit)
-    if ret:
-        ret = ret.lower()
-    return ret
-
-
 def has_verified_email(user, email=None) -> bool:
     from .models import EmailAddress
 
@@ -280,30 +219,6 @@ def setup_user_email(request, user, addresses):
     return primary
 
 
-def send_email_confirmation(request, user, signup=False, email=None) -> bool:
-    return flows.email_verification.send_verification_email(
-        request, user, signup=signup, email=email
-    )
-
-
-def sync_user_email_addresses(user):
-    """
-    Keep user.email in sync with user.emailaddress_set.
-
-    Under some circumstances the user.email may not have ended up as
-    an EmailAddress record, e.g. in the case of manually created admin
-    users.
-    """
-    from .models import EmailAddress
-
-    email = user_email(user)
-    if email and not EmailAddress.objects.filter(user=user, email=email).exists():
-        # get_or_create() to gracefully handle races
-        EmailAddress.objects.get_or_create(
-            user=user, email=email, defaults={"primary": False, "verified": False}
-        )
-
-
 def filter_users_by_username(*username):
     if app_settings.PRESERVE_USERNAME_CASING:
         qlist = [
@@ -326,7 +241,7 @@ def filter_users_by_username(*username):
 
 def filter_users_by_email(
     email: str, is_active: Optional[bool] = None, prefer_verified: bool = False
-):
+) -> List:
     """Return list of users by email address
 
     Typically one, at most just a few in length.  First we look through
@@ -357,7 +272,7 @@ def filter_users_by_email(
     if app_settings.USER_MODEL_EMAIL_FIELD and not is_verified:
         q_dict = {app_settings.USER_MODEL_EMAIL_FIELD: email}
         user_qs = User.objects.filter(**q_dict)
-        for user in user_qs.iterator():
+        for user in user_qs.iterator(2000):
             user_email = getattr(user, app_settings.USER_MODEL_EMAIL_FIELD)
             if _unicode_ci_compare(user_email, email):
                 users.append(user)
