@@ -4,9 +4,10 @@ from django.http import HttpRequest
 
 from ninja.security.base import AuthBase
 
-from allauth.headless.internal.sessionkit import (
-    authenticate_by_x_session_token,
-)
+from allauth.core.internal.httpkit import get_authorization_credential
+from allauth.headless import app_settings
+from allauth.headless.internal.sessionkit import authenticate_by_x_session_token
+from allauth.headless.tokens.strategies.jwt.internal import validate_access_token
 
 
 class XSessionTokenAuth(AuthBase):
@@ -35,3 +36,24 @@ class XSessionTokenAuth(AuthBase):
 
 
 x_session_token_auth = XSessionTokenAuth()
+
+
+class JWTTokenAuth(AuthBase):
+
+    openapi_type: str = "apiKey"
+
+    def __call__(self, request: HttpRequest):
+        token = get_authorization_credential(
+            request, app_settings.JWT_AUTHORIZATION_HEADER_SCHEME
+        )
+        if token is None:
+            return None
+        user_payload = validate_access_token(token)
+        if user_payload is None:
+            return None
+        user, payload = user_payload
+        request.user = user
+        return payload
+
+
+jwt_token_auth = JWTTokenAuth()
