@@ -1,20 +1,14 @@
 from allauth.socialaccount.providers.base import ProviderAccount
-from allauth.socialaccount.providers.instagram.views import (
-    InstagramOAuth2Adapter,
-)
+from allauth.socialaccount.providers.instagram.views import InstagramOAuth2Adapter
 from allauth.socialaccount.providers.oauth2.provider import OAuth2Provider
 
 
 class InstagramAccount(ProviderAccount):
-    PROFILE_URL = "http://instagram.com/"
+    PROFILE_URL = "https://instagram.com/"
 
     def get_profile_url(self):
         return self.PROFILE_URL + self.account.extra_data.get("username")
 
-    def to_str(self):
-        dflt = super(InstagramAccount, self).to_str()
-        return self.account.extra_data.get("username", dflt)
-
 
 class InstagramProvider(OAuth2Provider):
     id = "instagram"
